pub enum PostOffsetStrategy {
Absolute,
Padded,
PreOffset,
Relative,
}Expand description
How a post-offset modifier interprets its offset value after serialising the wrapped type.
Variants
Absolute
Move the cursor to the absolute byte position given by the offset.
Padded
Pad with zero bytes from the current cursor up to the offset bytes ahead.
PreOffset
Restore the cursor to where it was before the wrapped type ran (cancelling its pre-offset).
Relative
Advance the cursor by the offset bytes relative to its current position.