pub enum PreOffsetStrategy {
Absolute,
Padded,
Relative,
}Expand description
How a pre-offset modifier interprets its offset value before serialising the wrapped type.
Variants
Absolute
Move the cursor to the absolute byte position given by the offset.
Padded
Pad with zero bytes from the current cursor up to the offset bytes ahead.
Relative
Advance the cursor by the offset bytes relative to its current position.