pub enum ProgramOrigin {
Anchor,
Shank,
}Expand description
The toolchain that originally generated a program description.
Variants
Anchor
The program was originally described by an Anchor IDL.
Shank
The program was originally described by a Shank IDL.